@@ -4,7 +4,7 @@ use 5.008_003;
 
 package SWISH::3;
 
-our $VERSION = '1.000008';
+our $VERSION = '1.000009';
 my $version = $VERSION;
 $VERSION = eval $VERSION;    # numerify
 
@@ -196,6 +196,39 @@ sub default_handler {
     }
 }
 
+{
+    package    # hide from CPAN
+        SWISH::3::xml2TiedHash;
+
+    use overload (
+        '%{}'    => sub { shift->_as_hash() },
+        bool     => sub {1},
+        fallback => 1,
+    );
+
+    sub _as_hash {
+        my $self = shift;
+        my %tmp = map { $_ => $self->get($_) } @{ $self->keys };
+        return \%tmp;
+    }
+
+}
+{
+    package    # hide
+        SWISH::3::xml2Hash;
+    our @ISA = ('SWISH::3::xml2TiedHash');
+}
+{
+    package    # hide
+        SWISH::3::PropertyHash;
+    our @ISA = ('SWISH::3::xml2TiedHash');
+}
+{
+    package    # hide
+        SWISH::3::MetaNameHash;
+    our @ISA = ('SWISH::3::xml2TiedHash');
+}
+
 1;
 
 __END__
@@ -515,32 +548,60 @@ file is parsed).
 
 =head2 set_properties
 
+Not yet implemented.
+
 =head2 get_properties
 
+Returns SWISH::3::PropertyHash object.
+
 =head2 set_metanames
 
+Not yet implemented.
+
 =head2 get_metanames
 
+Returns SWISH::3::MetaNameHash object.
+
 =head2 set_mimes
 
+Not yet implemented.
+
 =head2 get_mimes
 
+Returns SWISH::3::xml2Hash object.
+
 =head2 set_parsers
 
+Not yet implemented.
+
 =head2 get_parsers
 
+Returns SWISH::3::xml2Hash object.
+
 =head2 set_aliases
 
+Not yet implemented.
+
 =head2 get_aliases
 
+Returns SWISH::3::xml2Hash object.
+
 =head2 set_index
 
+Not yet implemented.
+
 =head2 get_index
 
+Returns SWISH::3::xml2Hash object.
+
 =head2 set_misc
 
+Not yet implemented.
+
 =head2 get_misc
 
+Returns SWISH::3::xml2Hash object.
+
 =head2 debug
 
 =head2 add(I<file_or_xml>)
@@ -553,6 +614,8 @@ delete() is B<NOT YET IMPLEMENTED>.
 
 =head2 read( I<filename> )
 
+Returns SWISH::3::Config object.
+
 =head2 write( I<filename> )
 
 =head1 SWISH::3::Data
